@@ -31,24 +31,17 @@ class CtrlOScope : public wxControl {
   virtual ~CtrlOScope();
   void OnPaint(wxPaintEvent& event);
   void OnSize(wxSizeEvent& event);
-  void PaintAll(wxDC& dc);
-  void PaintAllFunction(wxDC& dc);
   void OnEraseBackground(wxEraseEvent& WXUNUSED(event)){};
 
-  void AppendPoints(double dNewPoint[], int iTrack = 0);
-  void SetTrack(double dTrack[], int iTrack = 0);
   void SetXRange(double dLower, double dUpper, int logrange);
-  void SetYRange(double dLower, double dUpper, int logrange, int itrack);
+  void SetYRange(double dLower, double dUpper, int logrange);
   void SetFsample(int fsampling);
 
   void SetXUnits(wxString string, wxString XMin = "", wxString XMax = "");
   void SetYUnits(wxString string, wxString YMin = "", wxString YMax = "");
-  void SetGridColor(wxColour color);
-  void SetPlotColor(wxColour color, int iTrack = 0);
-  void SetBackgroundColor(wxColour color);
-  void Reset(int iTrack = 0);
-  void SetTrack(wxArrayDouble ardbl);
-  void SetTrack2(wxArrayDouble ardbl);
+  void SetTrack1(wxArrayDouble& ardbl);
+  void SetTrack2(wxArrayDouble& ardbl);
+  void SetTrackX(wxArrayDouble& ardbl);
   void SetNumOfVerticals(int num) { m_NumberOfVerticals = num; };
 
   void ShowUserText(wxString text, int xpos, int ypos) {
@@ -60,8 +53,9 @@ class CtrlOScope : public wxControl {
  protected:
   int m_fsampling;
 
-  wxArrayDouble m_points;
+  wxArrayDouble m_points1;
   wxArrayDouble m_points2;
+  wxArrayDouble m_pointsX;
   double m_MaxXValue;
   double m_MinXValue;
   double m_MaxYValue;
@@ -82,5 +76,16 @@ class CtrlOScope : public wxControl {
   wxString m_UserText;
   int m_UserTextPosX;
   int m_UserTextPosY;
+
+ private:
+  void PaintAll(wxDC& dc);
+  void PaintGraph(wxDC& dc);
+  void PaintTrack(wxDC& dc, size_t from, size_t to, double xstep, wxColor color,
+                  wxArrayDouble& points);
+  int ldist = 0;   // legend space on the left
+  int rdist = 20;  // space on the right
+  int tdist = 10;  // space on top
+  int bdist = 0;   // legend space on bottom
+  int udist = 0;   // unit text space
 };
 #endif  // __CTRLOSCOPE_H__
